summaryrefslogtreecommitdiff
path: root/FS/FS/payby.pm
diff options
context:
space:
mode:
authorIvan Kohler <ivan@freeside.biz>2015-02-10 01:38:56 -0800
committerIvan Kohler <ivan@freeside.biz>2015-02-10 01:38:56 -0800
commita4d4d3df88b33a6db30b565921f6d62efb252351 (patch)
tree0ddfa8fe885dfe6776a0c074aed9e1e0735a7cd7 /FS/FS/payby.pm
parent6615733676adb431ae48c78ce24758fe571614c1 (diff)
multiple payment options, RT#23741
Diffstat (limited to 'FS/FS/payby.pm')
-rw-r--r--FS/FS/payby.pm27
1 files changed, 6 insertions, 21 deletions
diff --git a/FS/FS/payby.pm b/FS/FS/payby.pm
index c4aa1b1..13423c4 100644
--- a/FS/FS/payby.pm
+++ b/FS/FS/payby.pm
@@ -5,7 +5,6 @@ use vars qw(%hash %payby2bop);
use Tie::IxHash;
use Business::CreditCard;
-
=head1 NAME
FS::payby - Object methods for payment type records
@@ -39,9 +38,8 @@ Payment types.
=cut
# paybys can be any/all of:
# - a customer payment type (cust_main.payby)
# - a payment or refund type (cust_pay.payby, cust_pay_batch.payby, cust_refund.payby)
-# - an event type (part_bill_event.payby)
tie %hash, 'Tie::IxHash',
'CARD' => {
@@ -70,18 +68,6 @@ tie %hash, 'Tie::IxHash',
cust_pay => 'CHEK', #this is a customer type only, payments are CHEK...
realtime => 1,
},
- #'LECB' => {
- # tinyname => 'phone bill',
- # shortname => 'Phone bill billing',
- # longname => 'Phone bill billing',
- # realtime => 1,
- #},
- 'BILL' => {
- tinyname => 'billing',
- shortname => 'Billing',
- payname => 'Check',
- longname => 'Billing',
- },
'PPAL' => {
tinyname => 'PayPal',
shortname => 'PayPal',
@@ -143,12 +129,6 @@ tie %hash, 'Tie::IxHash',
longname => 'Wire transfer',
cust_main => '', #not a customer type
},
- 'COMP' => {
- tinyname => 'comp',
- shortname => 'Complimentary',
- longname => 'Complimentary',
- cust_pay => '', # (free) is depricated as a payment type in cust_pay
- },
'CBAK' => {
tinyname => 'chargeback',
shortname => 'Chargeback',
@@ -234,6 +214,11 @@ sub cust_payby {
grep { ! exists $hash{$_}->{cust_main} } $self->payby;
}
+sub cust_payby2shortname {
+ my $self = shift;
+ map { $_ => $hash{$_}->{shortname} } $self->cust_payby;
+}
+
sub cust_payby2longname {
my $self = shift;
map { $_ => $hash{$_}->{longname} } $self->cust_payby;
@@ -39,9 +38,8 @@ Payment types.
=cut
# paybys can be any/all of:
-# - a customer payment type (cust_main.payby)
+# - a customer saved payment type (cust_payby.payby)
# - a payment or refund type (cust_pay.payby, cust_pay_batch.payby, cust_refund.payby)